@@ -1,7 +1,7 @@
 package Games::Hangman;
 
-our $DATE = '2016-10-19'; # DATE
-our $VERSION = '0.05'; # VERSION
+our $DATE = '2017-03-05'; # DATE
+our $VERSION = '0.06'; # VERSION
 
 #use Color::ANSI::Util qw(ansibg ansifg);
 use Module::List qw(list_modules);
@@ -19,6 +19,7 @@ has list              => (is => 'rw');
 has wl                => (is => 'rw');
 has list_type         => (is => 'rw'); # either (w)ord or (p)hrase
 has min_len           => (is => 'rw');
+has max_len           => (is => 'rw');
 has current_word      => (is => 'rw');
 has num_words         => (is => 'rw', default=>0); # words that have been played
 has num_guessed_words => (is => 'rw', default=>0); # have been guessed correctly
@@ -229,9 +230,11 @@ sub new_word {
                 next if $word =~ /[^\x20-\x7f]/;
             }
 
-            if (length($word) >= $self->min_len) {
-                last PICK;
-            }
+            next if $self->min_len && length($word) < $self->min_len;
+            next if $self->max_len && length($word) > $self->max_len;
+
+            # accept
+            last PICK;
         }
         die "Can't find eligible word from list ".$self->list."\n";
     }
@@ -434,7 +437,7 @@ Games::Hangman - A text-based hangman
 
 =head1 VERSION
 
-This document describes version 0.05 of Games::Hangman (from Perl distribution Games-Hangman), released on 2016-10-19.
+This document describes version 0.06 of Games::Hangman (from Perl distribution Games-Hangman), released on 2017-03-05.
 
 =head1 SYNOPSIS
 
@@ -468,7 +471,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017, 2016, 2015, 2014 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
